@@ -27,29 +27,32 @@
  * See the ChangeLog files for a list of changes. 
  */
 
-#include <glade/glade-xml.h>
-#include <libgnome/gnome-i18n.h>
-
-#include <pango/pango-break.h>
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <string.h> /* For strlen (...) */
 
-#include <gedit-plugin.h>
-#include <gedit-debug.h>
-#include <gedit-menus.h>
-#include <gedit-utils.h>
+#include <glib/gi18n.h>
+#include <glade/glade-xml.h>
+#include <pango/pango-break.h>
 
-#define MENU_ITEM_LABEL		N_("_Word Count")
-#define MENU_ITEM_PATH		"/menu/Search/SearchOps_3/"
+#include <gedit/gedit-plugin.h>
+#include <gedit/gedit-debug.h>
+#include <gedit/gedit-menus.h>
+#include <gedit/gedit-utils.h>
+
+#define MENU_ITEM_LABEL		N_("_Document Statistics")
+#define MENU_ITEM_PATH		"/menu/Tools/ToolsOps_2/"
 #define MENU_ITEM_NAME		"PluginWordCount"	
-#define MENU_ITEM_TIP		N_("Get info on current document.")
+#define MENU_ITEM_TIP		N_("Get statistic info on current document")
 
 typedef struct _DocInfoDialog DocInfoDialog;
 
 struct _DocInfoDialog {
 	GtkWidget *dialog;
 
-	GtkWidget *frame;
+	GtkWidget *file_name_label;
 	GtkWidget *lines_label;
 	GtkWidget *words_label;
 	GtkWidget *chars_label;
@@ -98,7 +101,6 @@ dialog_response_handler (GtkDialog *dlg, gint res_id,  DocInfoDialog *dialog)
 	}
 }
 
-
 static DocInfoDialog*
 get_dialog ()
 {
@@ -114,31 +116,27 @@ get_dialog ()
 
 	if (dialog != NULL)
 	{
-		gdk_window_show (dialog->dialog->window);
-		gdk_window_raise (dialog->dialog->window);
-		gtk_widget_grab_focus (dialog->dialog);
-
 		gtk_window_set_transient_for (GTK_WINDOW (dialog->dialog),
 				window);
-	
-		if (!GTK_WIDGET_VISIBLE (dialog->dialog))
-			gtk_widget_show (dialog->dialog);
+		gtk_window_present (GTK_WINDOW (dialog->dialog));
+		gtk_widget_grab_focus (dialog->dialog);
 
 		return dialog;
 	}
 
 	gui = glade_xml_new (GEDIT_GLADEDIR "docinfo.glade2",
 			     "docinfo_dialog_content", NULL);
-
-	if (!gui) {
-		g_warning
-		    ("Could not find docinfo.glade2, reinstall gedit.\n");
+	if (!gui)
+	{
+		gedit_warning (window,
+			       MISSING_FILE,	
+			       GEDIT_GLADEDIR "docinfo.glade2");
 		return NULL;
 	}
 
 	dialog = g_new0 (DocInfoDialog, 1);
 
-	dialog->dialog = gtk_dialog_new_with_buttons (_("Word count"),
+	dialog->dialog = gtk_dialog_new_with_buttons (_("Document Statistics"),
 						      window,
 						      GTK_DIALOG_DESTROY_WITH_PARENT,
 						      GTK_STOCK_CLOSE,
@@ -147,27 +145,34 @@ get_dialog ()
 
 	g_return_val_if_fail (dialog->dialog != NULL, NULL);
 
+	gtk_window_set_resizable (GTK_WINDOW (dialog->dialog), FALSE);
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog->dialog), FALSE);
+
 	/* Add the update button */
 	gedit_dialog_add_button (GTK_DIALOG (dialog->dialog), 
 				 _("_Update"), GTK_STOCK_REFRESH, GTK_RESPONSE_OK);
 
-	content			= glade_xml_get_widget (gui, "docinfo_dialog_content");
-
-	g_return_val_if_fail (content != NULL, NULL);
-
-	dialog->frame		= glade_xml_get_widget (gui, "frame");
+	content	= glade_xml_get_widget (gui, "docinfo_dialog_content");
+	dialog->file_name_label	= glade_xml_get_widget (gui, "file_name_label");
 	dialog->words_label	= glade_xml_get_widget (gui, "words_label");
 	dialog->bytes_label	= glade_xml_get_widget (gui, "bytes_label");
 	dialog->lines_label	= glade_xml_get_widget (gui, "lines_label");
 	dialog->chars_label	= glade_xml_get_widget (gui, "chars_label");
 	dialog->chars_ns_label	= glade_xml_get_widget (gui, "chars_ns_label");
 
-	g_return_val_if_fail (dialog->frame              != NULL, NULL);
-	g_return_val_if_fail (dialog->words_label        != NULL, NULL);
-	g_return_val_if_fail (dialog->bytes_label        != NULL, NULL);
-	g_return_val_if_fail (dialog->lines_label        != NULL, NULL);
-	g_return_val_if_fail (dialog->chars_label        != NULL, NULL);
-	g_return_val_if_fail (dialog->chars_ns_label     != NULL, NULL);
+	if (!content ||
+	    !dialog->file_name_label ||
+	    !dialog->words_label     ||
+	    !dialog->bytes_label     ||
+	    !dialog->lines_label     ||
+	    !dialog->chars_label     ||
+	    !dialog->chars_ns_label)
+	{
+		gedit_warning (window,
+			       MISSING_WIDGETS,
+			       GEDIT_GLADEDIR "docinfo.glade2");
+		return NULL;
+	}
 
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox),
 			    content, FALSE, FALSE, 0);
@@ -176,15 +181,13 @@ get_dialog ()
 					 GTK_RESPONSE_OK);
 
 	g_signal_connect (G_OBJECT (dialog->dialog), "destroy",
-			   G_CALLBACK (dialog_destroyed), &dialog);
+			  G_CALLBACK (dialog_destroyed), &dialog);
 
 	g_signal_connect (G_OBJECT (dialog->dialog), "response",
-			   G_CALLBACK (dialog_response_handler), dialog);
+			  G_CALLBACK (dialog_response_handler), dialog);
 
 	g_object_unref (gui);
 
-	gtk_window_set_resizable (GTK_WINDOW (dialog->dialog), FALSE);
-
 	gtk_widget_show (dialog->dialog);
 
 	return dialog;
@@ -205,6 +208,7 @@ word_count_real (void)
 	DocInfoDialog *dialog;
 
 	GeditDocument 	*doc;
+	GtkTextIter	 start, end;
 	gchar		*text;
 	PangoLogAttr 	*attrs;
 	gint		 words = 0;
@@ -214,14 +218,13 @@ word_count_real (void)
 	gint 		 bytes = 0;
 	gint		 i;
 	gchar		*tmp_str;
+	gchar 		*file_name;
 
 	gedit_debug (DEBUG_PLUGINS, "");
 
 	dialog = get_dialog ();
-	if (dialog == NULL) {
-		g_warning ("Could not create the Word Count dialog");
+	if (!dialog)
 		return;
-	}
 
 	doc = gedit_get_active_document ();
 
@@ -231,11 +234,14 @@ word_count_real (void)
 		return;
 	}
 
-	text = gedit_document_get_buffer (doc);
+	gtk_text_buffer_get_bounds (GTK_TEXT_BUFFER (doc), &start, &end);
+	text = gtk_text_buffer_get_slice (GTK_TEXT_BUFFER (doc),
+					   &start, &end, TRUE);
+
 	g_return_if_fail (g_utf8_validate (text, -1, NULL));
 
-	lines = gedit_document_get_line_count (doc);
-	
+	lines = gtk_text_buffer_get_line_count (GTK_TEXT_BUFFER (doc));
+
 	chars = g_utf8_strlen (text, -1);
  	attrs = g_new0 (PangoLogAttr, chars + 1);
 
@@ -246,17 +252,13 @@ word_count_real (void)
                        attrs,
                        chars + 1);
 
-	i = 0;
-	
-	while (i < chars)
+	for (i = 0; i < chars; i++)
 	{
 		if (attrs [i].is_white)
 			++white_chars;
 
 		if (attrs [i].is_word_start)
 			++words;
-
-		++i;
 	}
 
 	if (chars == 0)
@@ -271,8 +273,10 @@ word_count_real (void)
 	g_free (attrs);
 	g_free (text);
 
-	tmp_str = gedit_document_get_short_name (doc);
-	gtk_frame_set_label (GTK_FRAME (dialog->frame), tmp_str);
+	file_name = gedit_document_get_short_name (doc);
+	tmp_str = g_strdup_printf ("<span weight=\"bold\">%s</span>", file_name);
+	gtk_label_set_markup (GTK_LABEL (dialog->file_name_label), tmp_str);
+	g_free (file_name);
 	g_free (tmp_str);
 
 	tmp_str = g_strdup_printf("%d", lines);
@@ -294,9 +298,6 @@ word_count_real (void)
 	tmp_str = g_strdup_printf("%d", bytes);
 	gtk_label_set_text (GTK_LABEL (dialog->bytes_label), tmp_str);
 	g_free (tmp_str);
-
-
-		
 }
 
 G_MODULE_EXPORT GeditPluginState
@@ -358,18 +359,8 @@ init (GeditPlugin *pd)
 	/* initialize */
 	gedit_debug (DEBUG_PLUGINS, "");
      
-	pd->name = _("Word count");
-	pd->desc = _("The word count plugin analyzes the current document and determines the number "
-		     "of words, lines, characters and non-space characters in it "
-		     "and display the result.");
-	pd->author = "Paolo Maggi <maggi@athena.polito.it>";
-	pd->copyright = _("Copyright (C) 2002 - Paolo Maggi");
-	
 	pd->private_data = NULL;
 		
 	return PLUGIN_OK;
 }
 
-
-
-
